pub enum Error {
Io(Error),
NotBzImage,
ProtocolTooOld {
version: u16,
},
NotLoadedHigh,
No64BitEntry,
Truncated {
size: u64,
entry_offset: u64,
},
}Expand description
Errors that can occur during bzImage detection and parsing.
Variants
Io(Error)
An I/O error occurred while reading the bzImage.
NotBzImage
The image is not a valid bzImage (missing boot flag or HdrS magic).
ProtocolTooOld
The bzImage boot protocol version is too old.
NotLoadedHigh
The kernel does not support being loaded high (at 0x100000).
No64BitEntry
The kernel does not have a 64-bit entry point.
Truncated
The bzImage is truncated — the protected-mode code is too small to contain the 64-bit entry point.