is_bzimage

Function is_bzimage 

pub fn is_bzimage(kernel_image: &mut (impl Read + Seek)) -> Result<bool, Error>
Attempt to detect whether kernel_image is a bzImage.

Returns true if the image has a valid Linux setup header with the “HdrS” magic. The file position is always restored to the beginning before returning.