parse_bzimage

Function parse_bzimage 

pub fn parse_bzimage(
    kernel_image: &mut (impl Read + Seek),
) -> Result<BzImageInfo, Error>
Parse the bzImage setup header and return information needed for loading.

The file position of kernel_image is restored to the beginning on success. On error, restoration is best-effort (the seek-back is attempted but its failure is ignored in favor of the parse error).