LoadInfo

Struct LoadInfo 

pub struct LoadInfo {
    pub kernel: KernelInfo,
    pub initrd: Option<InitrdInfo>,
    pub dtb: Option<Range<u64>>,
    pub bzimage_setup_header: Option<setup_header>,
}
Information returned about where certain parts were loaded.

Fields

kernel: KernelInfo

The information about the kernel loaded.

initrd: Option<InitrdInfo>

The information about the initrd loaded.

dtb: Option<Range<u64>>

The information about the device tree blob loaded.

bzimage_setup_header: Option<setup_header>

If a bzImage was loaded, the original setup header from the image. This must be placed into the zero page so the kernel’s startup code can read its own configuration.