Struct TdispCommandRequestGetDeviceInterfaceInfo
pub struct TdispCommandRequestGetDeviceInterfaceInfo {
pub guest_protocol_type: i32,
}Expand description
Request the device’s TDISP interface information. Carries no payload.
Fields
guest_protocol_type: i32The type of CVM technology requested by the guest to drive the TDISP machinery.
Implementations
impl TdispCommandRequestGetDeviceInterfaceInfo
impl TdispCommandRequestGetDeviceInterfaceInfo
pub fn guest_protocol_type(&self) -> TdispGuestProtocolType
pub fn guest_protocol_type(&self) -> TdispGuestProtocolType
Returns the enum value of guest_protocol_type, or the default if the field is set to an invalid enum value.
pub fn set_guest_protocol_type(&mut self, value: TdispGuestProtocolType)
pub fn set_guest_protocol_type(&mut self, value: TdispGuestProtocolType)
Sets guest_protocol_type to the provided enum value.