Struct windows::Error [−][src]
pub struct Error { /* fields omitted */ }A WinRT error object consists of both an error code as well as detailed error information for debugging.
Implementations
impl Error[src]
impl Error[src]pub fn new(code: HRESULT, message: &str) -> Self[src]
This creates a new WinRT error object, capturing the stack and other information about the point of failure.
pub fn fast_error(code: HRESULT) -> Self[src]
pub fn code(&self) -> HRESULT[src]
The error code describing the error.
pub fn info(&self) -> &Option<IRestrictedErrorInfo>[src]
The error information describing the error.
pub fn message(&self) -> String[src]
The error message describing the error.