#[repr(C)]pub struct SevAvicPage {Show 37 fields
pub reserved_0: [ApicRegisterValue; 2],
pub id: ApicRegisterValue,
pub version: ApicRegisterValue,
pub reserved_4: [ApicRegisterValue; 4],
pub tpr: ApicRegisterValue,
pub apr: ApicRegisterValue,
pub ppr: ApicRegisterValue,
pub eoi: ApicRegisterValue,
pub rrd: ApicRegisterValue,
pub ldr: ApicRegisterValue,
pub dfr: ApicRegisterValue,
pub svr: ApicRegisterValue,
pub isr: [ApicRegisterValue; 8],
pub tmr: [ApicRegisterValue; 8],
pub irr: [SevAvicIrrRegister; 8],
pub esr: ApicRegisterValue,
pub reserved_29: [ApicRegisterValue; 6],
pub lvt_cmci: ApicRegisterValue,
pub icr: [ApicRegisterValue; 2],
pub lvt_timer: ApicRegisterValue,
pub lvt_thermal: ApicRegisterValue,
pub lvt_pmc: ApicRegisterValue,
pub lvt_lint0: ApicRegisterValue,
pub lvt_lint1: ApicRegisterValue,
pub lvt_error: ApicRegisterValue,
pub timer_icr: ApicRegisterValue,
pub timer_ccr: ApicRegisterValue,
pub reserved_3a: [ApicRegisterValue; 4],
pub timer_dcr: ApicRegisterValue,
pub self_ipi: ApicRegisterValue,
pub eafr: ApicRegisterValue,
pub eacr: ApicRegisterValue,
pub seoi: ApicRegisterValue,
pub reserved_44: [ApicRegisterValue; 5],
pub ier: [ApicRegisterValue; 8],
pub ei_lv_tr: [ApicRegisterValue; 3],
pub reserved_54: [ApicRegisterValue; 173],
}Expand description
Structure representing the SEV-ES AVIC backing page. Specification: “AMD64 PPR Vol3 System Programming”, 15.29.3 AVIC Backing Page.
Fields
reserved_0: [ApicRegisterValue; 2]id: ApicRegisterValueversion: ApicRegisterValuereserved_4: [ApicRegisterValue; 4]tpr: ApicRegisterValueapr: ApicRegisterValueppr: ApicRegisterValueeoi: ApicRegisterValuerrd: ApicRegisterValueldr: ApicRegisterValuedfr: ApicRegisterValuesvr: ApicRegisterValueisr: [ApicRegisterValue; 8]tmr: [ApicRegisterValue; 8]irr: [SevAvicIrrRegister; 8]esr: ApicRegisterValuereserved_29: [ApicRegisterValue; 6]lvt_cmci: ApicRegisterValueicr: [ApicRegisterValue; 2]lvt_timer: ApicRegisterValuelvt_thermal: ApicRegisterValuelvt_pmc: ApicRegisterValuelvt_lint0: ApicRegisterValuelvt_lint1: ApicRegisterValuelvt_error: ApicRegisterValuetimer_icr: ApicRegisterValuetimer_ccr: ApicRegisterValuereserved_3a: [ApicRegisterValue; 4]timer_dcr: ApicRegisterValueself_ipi: ApicRegisterValueeafr: ApicRegisterValueeacr: ApicRegisterValueseoi: ApicRegisterValuereserved_44: [ApicRegisterValue; 5]ier: [ApicRegisterValue; 8]ei_lv_tr: [ApicRegisterValue; 3]reserved_54: [ApicRegisterValue; 173]Trait Implementations
Sourceimpl Clone for SevAvicPage
impl Clone for SevAvicPage
Sourcefn clone(&self) -> SevAvicPage
fn clone(&self) -> SevAvicPage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SevAvicPage
impl Debug for SevAvicPage
Sourceimpl FromBytes for SevAvicPagewhere
[ApicRegisterValue; 2]: FromBytes,
ApicRegisterValue: FromBytes,
[ApicRegisterValue; 4]: FromBytes,
[ApicRegisterValue; 8]: FromBytes,
[SevAvicIrrRegister; 8]: FromBytes,
[ApicRegisterValue; 6]: FromBytes,
[ApicRegisterValue; 5]: FromBytes,
[ApicRegisterValue; 3]: FromBytes,
[ApicRegisterValue; 173]: FromBytes,
impl FromBytes for SevAvicPagewhere
[ApicRegisterValue; 2]: FromBytes,
ApicRegisterValue: FromBytes,
[ApicRegisterValue; 4]: FromBytes,
[ApicRegisterValue; 8]: FromBytes,
[SevAvicIrrRegister; 8]: FromBytes,
[ApicRegisterValue; 6]: FromBytes,
[ApicRegisterValue; 5]: FromBytes,
[ApicRegisterValue; 3]: FromBytes,
[ApicRegisterValue; 173]: FromBytes,
fn ref_from_bytes(
source: &[u8],
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout + Immutable,
fn ref_from_bytes(
source: &[u8],
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout + Immutable,
fn ref_from_prefix(
source: &[u8],
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout + Immutable,
fn ref_from_prefix(
source: &[u8],
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout + Immutable,
fn ref_from_suffix(
source: &[u8],
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: Immutable + KnownLayout,
fn ref_from_suffix(
source: &[u8],
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: Immutable + KnownLayout,
Interprets the suffix of the given bytes as a
&Self. Read morefn mut_from_bytes(
source: &mut [u8],
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout,
fn mut_from_bytes(
source: &mut [u8],
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout,
fn mut_from_prefix(
source: &mut [u8],
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout,
fn mut_from_prefix(
source: &mut [u8],
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout,
fn mut_from_suffix(
source: &mut [u8],
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout,
fn mut_from_suffix(
source: &mut [u8],
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout,
fn ref_from_bytes_with_elems(
source: &[u8],
count: usize,
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn ref_from_bytes_with_elems(
source: &[u8],
count: usize,
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn ref_from_prefix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn ref_from_prefix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn ref_from_suffix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn ref_from_suffix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, Infallible>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn mut_from_bytes_with_elems(
source: &mut [u8],
count: usize,
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout<PointerMetadata = usize> + Immutable,
fn mut_from_bytes_with_elems(
source: &mut [u8],
count: usize,
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout<PointerMetadata = usize> + Immutable,
fn mut_from_prefix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout<PointerMetadata = usize>,
fn mut_from_prefix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout<PointerMetadata = usize>,
fn mut_from_suffix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout<PointerMetadata = usize>,
fn mut_from_suffix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, Infallible>>where
Self: IntoBytes + KnownLayout<PointerMetadata = usize>,
Sourceimpl FromZeros for SevAvicPagewhere
[ApicRegisterValue; 2]: FromZeros,
ApicRegisterValue: FromZeros,
[ApicRegisterValue; 4]: FromZeros,
[ApicRegisterValue; 8]: FromZeros,
[SevAvicIrrRegister; 8]: FromZeros,
[ApicRegisterValue; 6]: FromZeros,
[ApicRegisterValue; 5]: FromZeros,
[ApicRegisterValue; 3]: FromZeros,
[ApicRegisterValue; 173]: FromZeros,
impl FromZeros for SevAvicPagewhere
[ApicRegisterValue; 2]: FromZeros,
ApicRegisterValue: FromZeros,
[ApicRegisterValue; 4]: FromZeros,
[ApicRegisterValue; 8]: FromZeros,
[SevAvicIrrRegister; 8]: FromZeros,
[ApicRegisterValue; 6]: FromZeros,
[ApicRegisterValue; 5]: FromZeros,
[ApicRegisterValue; 3]: FromZeros,
[ApicRegisterValue; 173]: FromZeros,
fn new_zeroed() -> Selfwhere
Self: Sized,
fn new_zeroed() -> Selfwhere
Self: Sized,
Creates an instance of
Self from zeroed bytes. Read morefn new_box_zeroed() -> Result<Box<Self>, AllocError>where
Self: Sized,
fn new_box_zeroed() -> Result<Box<Self>, AllocError>where
Self: Sized,
Creates a
Box<Self> from zeroed bytes. Read morefn new_box_zeroed_with_elems(count: usize) -> Result<Box<Self>, AllocError>where
Self: KnownLayout<PointerMetadata = usize>,
fn new_box_zeroed_with_elems(count: usize) -> Result<Box<Self>, AllocError>where
Self: KnownLayout<PointerMetadata = usize>,
Creates a
Box<[Self]> (a boxed slice) from zeroed bytes. Read morefn new_vec_zeroed(len: usize) -> Result<Vec<Self>, AllocError>where
Self: Sized,
fn new_vec_zeroed(len: usize) -> Result<Vec<Self>, AllocError>where
Self: Sized,
Creates a
Vec<Self> from zeroed bytes. Read moreSourceimpl IntoBytes for SevAvicPagewhere
[ApicRegisterValue; 2]: IntoBytes,
ApicRegisterValue: IntoBytes,
[ApicRegisterValue; 4]: IntoBytes,
[ApicRegisterValue; 8]: IntoBytes,
[SevAvicIrrRegister; 8]: IntoBytes,
[ApicRegisterValue; 6]: IntoBytes,
[ApicRegisterValue; 5]: IntoBytes,
[ApicRegisterValue; 3]: IntoBytes,
[ApicRegisterValue; 173]: IntoBytes,
(): PaddingFree<Self, { _ }>,
impl IntoBytes for SevAvicPagewhere
[ApicRegisterValue; 2]: IntoBytes,
ApicRegisterValue: IntoBytes,
[ApicRegisterValue; 4]: IntoBytes,
[ApicRegisterValue; 8]: IntoBytes,
[SevAvicIrrRegister; 8]: IntoBytes,
[ApicRegisterValue; 6]: IntoBytes,
[ApicRegisterValue; 5]: IntoBytes,
[ApicRegisterValue; 3]: IntoBytes,
[ApicRegisterValue; 173]: IntoBytes,
(): PaddingFree<Self, { _ }>,
fn as_mut_bytes(&mut self) -> &mut [u8] ⓘwhere
Self: FromBytes,
fn as_mut_bytes(&mut self) -> &mut [u8] ⓘwhere
Self: FromBytes,
Gets the bytes of this value mutably. Read more
fn write_to(&self, dst: &mut [u8]) -> Result<(), SizeError<&Self, &mut [u8]>>where
Self: Immutable,
fn write_to(&self, dst: &mut [u8]) -> Result<(), SizeError<&Self, &mut [u8]>>where
Self: Immutable,
Sourceimpl KnownLayout for SevAvicPagewhere
[ApicRegisterValue; 173]: KnownLayout,
impl KnownLayout for SevAvicPagewhere
[ApicRegisterValue; 173]: KnownLayout,
Sourcetype PointerMetadata = <[ApicRegisterValue; 173] as KnownLayout>::PointerMetadata
type PointerMetadata = <[ApicRegisterValue; 173] as KnownLayout>::PointerMetadata
The type of metadata stored in a pointer to
Self. Read morefn size_for_metadata(meta: Self::PointerMetadata) -> Option<usize>
fn size_for_metadata(meta: Self::PointerMetadata) -> Option<usize>
Computes the size of an object of type
Self with the given pointer
metadata. Read moreSourceimpl TryFromBytes for SevAvicPagewhere
[ApicRegisterValue; 2]: TryFromBytes,
ApicRegisterValue: TryFromBytes,
[ApicRegisterValue; 4]: TryFromBytes,
[ApicRegisterValue; 8]: TryFromBytes,
[SevAvicIrrRegister; 8]: TryFromBytes,
[ApicRegisterValue; 6]: TryFromBytes,
[ApicRegisterValue; 5]: TryFromBytes,
[ApicRegisterValue; 3]: TryFromBytes,
[ApicRegisterValue; 173]: TryFromBytes,
impl TryFromBytes for SevAvicPagewhere
[ApicRegisterValue; 2]: TryFromBytes,
ApicRegisterValue: TryFromBytes,
[ApicRegisterValue; 4]: TryFromBytes,
[ApicRegisterValue; 8]: TryFromBytes,
[SevAvicIrrRegister; 8]: TryFromBytes,
[ApicRegisterValue; 6]: TryFromBytes,
[ApicRegisterValue; 5]: TryFromBytes,
[ApicRegisterValue; 3]: TryFromBytes,
[ApicRegisterValue; 173]: TryFromBytes,
fn try_ref_from_bytes(
source: &[u8],
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout + Immutable,
fn try_ref_from_bytes(
source: &[u8],
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout + Immutable,
fn try_ref_from_prefix(
source: &[u8],
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout + Immutable,
fn try_ref_from_prefix(
source: &[u8],
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout + Immutable,
fn try_ref_from_suffix(
source: &[u8],
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout + Immutable,
fn try_ref_from_suffix(
source: &[u8],
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout + Immutable,
fn try_mut_from_bytes(
bytes: &mut [u8],
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout + IntoBytes,
fn try_mut_from_bytes(
bytes: &mut [u8],
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout + IntoBytes,
fn try_mut_from_prefix(
source: &mut [u8],
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout + IntoBytes,
fn try_mut_from_prefix(
source: &mut [u8],
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout + IntoBytes,
fn try_mut_from_suffix(
source: &mut [u8],
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout + IntoBytes,
fn try_mut_from_suffix(
source: &mut [u8],
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout + IntoBytes,
fn try_ref_from_bytes_with_elems(
source: &[u8],
count: usize,
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn try_ref_from_bytes_with_elems(
source: &[u8],
count: usize,
) -> Result<&Self, ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn try_ref_from_prefix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn try_ref_from_prefix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&Self, &[u8]), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
Attempts to interpret the prefix of the given
source as a &Self with
a DST length equal to count. Read morefn try_ref_from_suffix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
fn try_ref_from_suffix_with_elems(
source: &[u8],
count: usize,
) -> Result<(&[u8], &Self), ConvertError<AlignmentError<&[u8], Self>, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + Immutable,
Attempts to interpret the suffix of the given
source as a &Self with
a DST length equal to count. Read morefn try_mut_from_bytes_with_elems(
source: &mut [u8],
count: usize,
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + IntoBytes,
fn try_mut_from_bytes_with_elems(
source: &mut [u8],
count: usize,
) -> Result<&mut Self, ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + IntoBytes,
fn try_mut_from_prefix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + IntoBytes,
fn try_mut_from_prefix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut Self, &mut [u8]), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + IntoBytes,
Attempts to interpret the prefix of the given
source as a &mut Self
with a DST length equal to count. Read morefn try_mut_from_suffix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + IntoBytes,
fn try_mut_from_suffix_with_elems(
source: &mut [u8],
count: usize,
) -> Result<(&mut [u8], &mut Self), ConvertError<AlignmentError<&mut [u8], Self>, SizeError<&mut [u8], Self>, ValidityError<&mut [u8], Self>>>where
Self: KnownLayout<PointerMetadata = usize> + IntoBytes,
Attempts to interpret the suffix of the given
source as a &mut Self
with a DST length equal to count. Read morefn try_read_from_bytes(
source: &[u8],
) -> Result<Self, ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_bytes(
source: &[u8],
) -> Result<Self, ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_prefix(
source: &[u8],
) -> Result<(Self, &[u8]), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_prefix(
source: &[u8],
) -> Result<(Self, &[u8]), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_suffix(
source: &[u8],
) -> Result<(&[u8], Self), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_suffix(
source: &[u8],
) -> Result<(&[u8], Self), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
impl Immutable for SevAvicPagewhere
[ApicRegisterValue; 2]: Immutable,
ApicRegisterValue: Immutable,
[ApicRegisterValue; 4]: Immutable,
[ApicRegisterValue; 8]: Immutable,
[SevAvicIrrRegister; 8]: Immutable,
[ApicRegisterValue; 6]: Immutable,
[ApicRegisterValue; 5]: Immutable,
[ApicRegisterValue; 3]: Immutable,
[ApicRegisterValue; 173]: Immutable,