pub struct BzImageInfo {
pub setup_header: setup_header,
pub setup_sects: u8,
pub protected_mode_size: u64,
pub entry_offset: u64,
pub init_size: u32,
}Expand description
Information parsed from a bzImage setup header, needed for loading.
Fields
setup_header: setup_headerThe setup header to copy into the zero page’s hdr field.
setup_sects: u8Number of setup sectors (determines where protected-mode code starts).
The protected-mode code begins at offset (setup_sects + 1) * 512 in the file.
protected_mode_size: u64The total size in bytes of the protected-mode code (everything after the setup).
entry_offset: u64The 64-bit entry point offset relative to the start of the protected-mode code. For protocol >= 2.12 with XLF_KERNEL_64, this is at offset 0x200 from the start of the protected-mode code.
init_size: u32The init_size field — the amount of linear contiguous memory the
kernel needs starting at the load address for initialization.