pub trait RegisterValue {
// Required methods
fn as_abi(&self) -> WHV_REGISTER_VALUE;
fn from_abi(value: &WHV_REGISTER_VALUE) -> Self;
}Expand description
Trait implemented by register value types.
Required Methods
Sourcefn as_abi(&self) -> WHV_REGISTER_VALUE
fn as_abi(&self) -> WHV_REGISTER_VALUE
Converts the value into the ABI register value.
Sourcefn from_abi(value: &WHV_REGISTER_VALUE) -> Self
fn from_abi(value: &WHV_REGISTER_VALUE) -> Self
Extracts the value from the ABI register value.
This may truncate the input, but as long as the ABI value actually stores a value associated with this register, no data will be lost.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.